pub enum TrackerMode {
Public,
Listed,
Private,
PrivateListed,
}Expand description
The mode the tracker will run in.
Refer to Torrust Tracker Configuration to know how to configure the tracker to run in each mode.
Variants
Public
Will track every new info hash and serve every peer.
Listed
Will only track whitelisted info hashes.
Private
Will only serve authenticated peers
PrivateListed
Will only track whitelisted info hashes and serve authenticated peers