pub struct SwarmMetadata {
pub downloaded: u32,
pub complete: u32,
pub incomplete: u32,
}Expand description
Swarm statistics for one torrent. Swarm metadata dictionary in the scrape response.
Fields
downloaded: u32(i.e completed): The number of peers that have ever completed downloading
complete: u32(i.e seeders): The number of active peers that have completed downloading (seeders)
incomplete: u32(i.e leechers): The number of active peers that have not completed downloading (leechers)
Implementations
Sourceimpl SwarmMetadata
impl SwarmMetadata
Sourceimpl SwarmMetadata
impl SwarmMetadata